pods
===

# Python open data science software. 

This repository contains utilities and tools for open data science including tools for accessing data sets in python. 



## Datasets

There is a set of notebooks describing the data sets that can be accessed available in the notebooks subdirectory. 

